(function() {
	/************************************
	 * GEOLocation
	 * 端末のGPS センサーの情報を取得する
	 ************************************/

	/*
	 * 変数の宣言
	 */
	var geolocationWatchID;	// 位置情報監視停止用のID

	/*
	 * 端末の現在位置を取得
	 */
	getCurrentPosition = function() {
		var options = {
			maximumAge         : 10000,
			timeout            : 30000,
			enableHighAccuracy : false
		};
		applican.geolocation.getCurrentPosition(currentPositionSuccess, currentPositionError, options);
	};

	/*
	 * GPSセンサーより位置情報を取得成功した時のコールバック
	 */
	currentPositionSuccess = function(res) {
		getPositionSuccess(res, "currentPositionSuccess");
	};

	/*
	 * GPSセンサーより位置情報を取得失敗した時のコールバック
	 */
	currentPositionError = function(error) {
		var dump = "currentPositionError\n";
		dump    += "code:"    + error.code    + "\n";
		dump    += "message:" + error.message + "\n";
		document.getElementById("dumpAreaGeolocation").value = dump;
	};

	/*
	 * 位置情報を一定の時間間隔で取得
	 * maximumAge		  : Number  キャッシュされた位置情報の取得を許容する最大時間指定する(ミリ秒)
	 * timeout			  : Number  コールバック関数が呼ばれるまでの最大経過時間指定する(ミリ秒)
	 * 								指定時間内で位置情報が取得できなければerrorCallback関数が呼ばれる
	 * enableHighAccuracy : boolean 高精度の位置情報を取得するか指定する項目
	 * 								falseの場合は、ネットワーク情報より位置情報取得を試みる
	 * 								trueの場合はGPS等の高精度な位置情報取得を試みる
	 * frequency		  : Number  一定間隔で位置情報を取得する際の間隔を指定する(ミリ秒)
	 */
	watchPosition = function() {
		var options = {
			maximumAge         : 0,
			timeout            : 20000,
			enableHighAccuracy : false,
			frequency          : 30000,
			distance           : 1,
			accuracy           : 10,
		};
		geolocationWatchID = applican.geolocation.watchPosition(watchPositionSuccess, watchPositionError, options);
	};

	/*
	 * 位置情報を一定の時間間隔で取得成功した時のコールバック
	 */
	watchPositionSuccess = function(res) {
		getPositionSuccess(res, "watchPositionSuccess");
	};

	/*
	 * 位置情報を一定の時間間隔で取得失敗した時のコールバック
	 */
	watchPositionError = function(e) {
		var dump = "watchPositionError\n";
		dump    += "code:"    + e.code    + "\n";
		dump    += "message:" + e.message + "\n";
		document.getElementById("dumpAreaGeolocation").value = dump;
	};

	/*
	 * 位置情報を取得成功した時の共通処理
	 */
	getPositionSuccess = function(res, funcName) {
		// 位置情報の出力(全て)
		var dump = funcName + "\n";
		dump    += "latitude:"         + res.coords.latitude         + "\n";
		dump    += "longitude:"        + res.coords.longitude        + "\n";
		dump    += "altitude:"         + res.coords.altitude         + "\n";
		dump    += "accuracy:"         + res.coords.accuracy         + "\n";
		dump    += "altitudeAccuracy:" + res.coords.altitudeAccuracy + "\n";
		dump    += "heading:"          + res.coords.heading          + "\n";
		dump    += "speed:"            + res.coords.speed            + "\n";
		dump    += "timestamp:"        + res.timestamp               + "\n";
		document.getElementById("dumpAreaGeolocation").value = dump;
		document.getElementById("map").style.display = "block";

		// 位置情報の出力(経度、緯度、海抜と経緯度の精度)
		var positionInfo = document.getElementById("positionInfo");
		var positionString  = "<b>現在あなたの位置情報：</b><br><br>";
		positionString     += "経度: " + res.coords.longitude + "°" + "<br>";
		positionString     += "緯度: " + res.coords.latitude  + "°" + "<br>";
		var altitude = res.coords.altitude;
		if (altitude !== null) {
			positionString += "海抜：" + res.coords.altitude + "メートル" + "<br>";
		}
		positionString     += "経緯度の精度：" + res.coords.accuracy + "メートル" + "<br>";
		positionInfo.innerHTML = positionString;

		// Google Map描画
		var latlng = new google.maps.LatLng(res.coords.latitude, res.coords.longitude);
		var myOptions = {
			zoom : 14,
			center : latlng,
			mapTypeId : google.maps.MapTypeId.ROADMAP
		};
		var map1;
		map1 = new google.maps.Map(document.getElementById("map"), myOptions);
		var marker = new google.maps.Marker({
			position : latlng,
			map : map1
		});
		var infowindow = new google.maps.InfoWindow({
			content : "現在の位置"
		});
		infowindow.open(map1, marker);
	};

	/*
	 * 位置情報の監視を停止
	 */
	clearWatchPosition = function() {
		applican.geolocation.clearWatch(geolocationWatchID);
		document.getElementById("dumpAreaGeolocation").value = "位置情報の監視を終了しました";
	};

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		//「現在位置を取得」ボタン押下時の処理
		document.getElementById("getPositionBtn").addEventListener("click", getCurrentPosition, false);
		//「現在位置を一定の時間間隔で取得」ボタン押下時の処理
		document.getElementById("watchPositionBtn").addEventListener("click", watchPosition, false);
		//「現在位置の監視を停止」ボタン押下時の処理
		document.getElementById("clearWatchBtn").addEventListener("click", clearWatchPosition, false);
	}, false);
})();
